#!/bin/sh

DESTDIR=/scratchbox/host_shared/lib

# copy libs
mkdir -p $DESTDIR
# make ldd work with our own spec-file linked binaries
if [ ! -e /scratchbox/host_shared/lib/ld-linux.so.2 ]; then
	# WARNING: dynamic linker name is hardcoded in here and spec file
	cp -a /lib/ld-linux.so.2 /scratchbox/host_shared/lib/
	if [ -L /lib/ld-linux.so.2 ]; then
		cp /lib/`readlink /lib/ld-linux.so.2` /scratchbox/host_shared/lib/
	fi
fi

BIN_FILES="/scratchbox/tools/bin/* /scratchbox/alien_tools/bin/*"

for i in `ls /scratchbox/devkits/`; do
	BIN_FILES="$BIN_FILES /scratchbox/devkits/$i/*"
done

for i in $(ldd $BIN_FILES 2>/dev/null | grep "=>" | cut -d ">" -f 2 | cut -d " " -f 2 | sort -u) ; do
	if [ -L "$i" ] ; then
		REALFILE=$(file $i | cut -d " " -f 5)
		if [ -e /etc/debian_version ]; then
			REALFILE=$(echo $REALFILE | sed "s/^\`//;s/'$//");
		fi
		d=$(dirname $i);
		if [ "$d" == "/lib/tls" ]; then
			d="/lib";
		fi
		if [ -e $d/$REALFILE ]; then
			cp $d/$REALFILE $DESTDIR
		fi
	else
		cp -u $i $DESTDIR
	fi
done

cp -du /lib/*nss* $DESTDIR
cp -du /lib/*nsl* $DESTDIR
cp -du /lib/libm* $DESTDIR
cp -du /usr/lib/libstd* $DESTDIR
cp -du /usr/lib/libgcc* $DESTDIR
cp -du /usr/lib/libz* $DESTDIR
cp -du /usr/lib/*crt* $DESTDIR
cp -du /usr/lib/libpthread* $DESTDIR
cp -du /lib/libpthread* $DESTDIR
cp -du /lib/libresolv* $DESTDIR
cp -du /usr/lib/libncurses* /usr/lib/libpanel* /usr/lib/libmenu* /usr/lib/libform* $DESTDIR
cp -Lu $(gcc -print-search-dirs | grep libraries | sed 's/.*=//'| awk -F: '{for (i=1;i<NF;i++) { print $i; }}' | grep gcc-lib | sed '/\.\./d')/*.so* $DESTDIR


if [ ! -e /etc/debian_version ]; then
# non-Debian system; we assume it is RedHat
	for f in $(rpm -ql libacl libacl-devel ncurses ncurses-devel libtermcap libtermcap-devel pcre pcre-devel zlib zlib-devel libstdc++ libstdc++-devel libgcc $(rpm -qa | grep glibc) | egrep "^/usr/include"); do 
		if [ ! -d $f ]; then install -D -p $f /scratchbox/host_shared$(echo $f | sed 's/^\/usr//'); fi
	done
else
# Debian/unstable system
	for f in $(dpkg -L libacl1 libacl1-dev libncurses5 libncurses5-dev libpcre3 libpcre3-dev zlib1g zlib1g-dev libstdc++5 libstdc++5-3.3-dev libgcc1 libc6 libc6-dev linux-kernel-headers | egrep "^/usr/include"); do
		if [ ! -d $f ]; then install -D -p $f /scratchbox/host_shared$(echo $f | sed 's/^\/usr//'); fi
	done
fi

for i in $(cd $DESTDIR && ls -1 *.so*); do
	I=$(echo $i | sed 's/\.so.*//')
	if [ -e "/usr/lib/$I.a" ] ; then
		cp -du /usr/lib/$I.a $DESTDIR
	fi
	if [ -e "/usr/lib/$I.la" ] ; then
		cp -du /usr/lib/$I.la $DESTDIR
	fi
done

for i in $DESTDIR/*.so* ; do
	if [ -L $i ]; then
		path=$(readlink $i)
		dir=$(dirname $path)
		if [ $dir != . ]; then
			name=$(basename $path)
			ln -sf $name $i
			if [ ! -e $DESTDIR/$name ]; then
				cp $path $DESTDIR/
			fi
		fi
	fi
done

# copy the static library libc.a also
cp -a /usr/lib/libc.a $DESTDIR

# create our own libc.so
if [ -e /usr/lib/libc_nonshared.a ]; then
	echo "GROUP ( $DESTDIR/libc.so.6 $DESTDIR/libc_nonshared.a )" > $DESTDIR/libc.so;
	cp -a /usr/lib/libc_nonshared.a $DESTDIR
fi
if [ -e /usr/lib/libpthread_nonshared.a ]; then
	echo "GROUP ( $DESTDIR/libpthread.so.0 $DESTDIR/libpthread_nonshared.a )" > $DESTDIR/libpthread.so;
fi
ln -fs libm.so.6 $DESTDIR/libm.so

/sbin/ldconfig -n $DESTDIR

# cp -dur /usr/share/locale /scratchbox/host_shared/nls_locale
# cp -dur /usr/lib/locale /scratchbox/host_shared/locale
cp -dur /usr/lib/gconv /scratchbox/host_shared/lib/

